#include <stdio.h>
#define  MAXLINES  25
#define  SPACE     " "

int process(char *progname, FILE *inp, FILE *out);
void pagehdr(FILE *out, int pageno);

int main(int argc, char *argv[])
  {
    int status;
    FILE *inp = stdin;  /* default input */
    FILE *out = stdout; /* and output */
    
    if (argc != 3 && argc != 1)
      {
        fprintf(stderr,
          "Usage: %s [<input> <output>]\n", argv[0]);
        return 1;
      }
    else if (argc == 3)
      {
        if ((inp = fopen(argv[1], "r")) == NULL)
          {
            fprintf(stderr,"%s: couldn't open %s\n",
                            argv[0], argv[1]);
            return 1;
          }
        if ((out = fopen(argv[2], "w")) == NULL)
          {
            fprintf(stderr,"%s: couldn't open %s\n",
                            argv[0], argv[2]);
            fclose(inp);
            return 1;
          }
      }

    status = process(argv[0], inp, out);

    if (argc == 3) { fclose(inp); fclose(out); }

    return status;
  }

int process(char *progname, FILE *inp, FILE *out)
  {
    int pageno = 0, linecnt = 0;
    float multiplier, quota, sales;
    char name[16];

    while (fscanf(inp,"%15s%4f%7f%7f", name,
             &multiplier, &quota, &sales) != EOF)
      {
        if (linecnt++ % MAXLINES == 0)
            pagehdr(out, ++pageno);

        fprintf(out,"%10s%-15s%7s%6.2f%9s%7.2f\n",
            SPACE, name, SPACE,
            (sales / quota) * 100, SPACE,
            sales > quota ?
            multiplier * (sales - quota) : 0);
      }

    if (ferror(inp))
      {
        fprintf(stderr,"%s: error in reading input\n",
                        progname);
        return 1;
      }
    else
        return 0;
  }
    
void pagehdr(FILE *out, int pageno)
  {
    fprintf(out,"\f%29sPage %2d\n\n\n", SPACE, pageno);
    fprintf(out,"%27sMEGA MICROS\n", SPACE);
    fprintf(out,"%21sSales Commission Report\n\n\n",
                 SPACE);
    fprintf(out,"%10sNAME%14sQUOTA ATTAINED"
                "%3sCOMMISSION\n\n",
                 SPACE, SPACE, SPACE);
  }
