/********************   io.c   *******************/

#include "global.h"

/*
 *  reads a data line into buf, discarding what cannot fit in buf.
 *  returns 0 on end-of-file and 1 + line length otherwise.
 */

static int readline(char *buf, int maxlen)
  {
    int c, len = 0;
    char *bufp = buf;

    while (c = getchar(), c != '\n' && c != EOF)
        if (len++ < maxlen && c != '\n' && c != EOF)
            *bufp++ = c;

    *bufp = '\0';  /* null terminate each line */
    
    return c == EOF && !len ? 0 : bufp - buf + 1;
  }

/*
 * saves input in a pointer array data,
 * with each element of the array pointing to a data line.
 * returns the number of data lines in input and -1 if the input is too large.
 */

int getdata(char **data, int maxlines)
  {
    int lines = 0, len;
    char buf[MAXLEN+1];

    /* first read a dataline into buf to determine its size, and
       then get the necessary storage */
    while (len = readline(buf, MAXLEN))
      {
        if (lines++ >= maxlines ||
            !(*data = (char *) malloc(len)))
                return -1;

       /* copy contents of buf into storage just allocated */
        strcpy(*data++, buf);
      }
    return lines;
  }

/*
 * print sorted data
 */

void printdata(char **data, int lines)
  {
    int i;

    for (i = 0; i < lines; i++)
        printf("%s\n", *data++);
  }
