#include <stdio.h>
#include <stdlib.h>
#define  ITEMS    1000

struct iteminfo
  {
    int   item;
    float price;
  };

struct node
  {
    struct iteminfo itemrec;
    struct node *lchild;
    struct node *rchild;
  };

struct node *bld_database(int items);
struct node *addtree(struct node *p,
                     int item, float price);
struct node *mknode(int item, float price);
struct iteminfo *search(int val, struct node *db);

int main(void)
  {
    struct node *database;
    struct iteminfo *ip;
    int    item_no;

    /* build the item-price database */
    if (!(database = bld_database(ITEMS)))
      {
        printf("too big a database\n");
        return 1;
      }

    /* read the item_no of the item whose price is to be found */
    scanf("%d", &item_no);

    /* search */
    ip = search(item_no, database);

    /* output */
    if (ip)
        printf("price of item %d = %f\n",
                item_no, ip->price);
    else
        printf("item %d is not in the database\n",
                item_no);

    return 0;
  }

struct node *bld_database(int items)
  {
    struct node *database = NULL;
    int item, i;
    float price;

    for (i = 0; i < items; i++)
      {
        scanf("%d %f", &item, &price);
        database = addtree(database, item, price);
        if (!database) return NULL;
      }
    return database;
  }

struct node *addtree(struct node *np,
                     int item, float price)
  {
    if (!np)
        np = mknode(item, price);
    else if (item > np->itemrec.item)
        np->lchild = addtree(np->lchild, item, price);
    else
        np->rchild = addtree(np->rchild, item, price);
    return np;
  }

struct node *mknode(int item, float price)
  {
    struct node *np;

    np = (struct node *) malloc(sizeof(struct node));
    if (np)
      {
        np->itemrec.item = item;
        np->itemrec.price = price;
        np->lchild = np->rchild = NULL;
      }
    return np;
  }

struct iteminfo *search(int val, struct node *db)
  {
    struct iteminfo *ip;

    if (!db)
        /* item not in the database */
        ip = NULL;
    else if (val == db->itemrec.item)
        /* found the item's record */
        ip = &db->itemrec;
    else if (val > db->itemrec.item)
        /* search the left subtree */
        ip = search(val, db->lchild);
    else
        /* search the right subtree */
        ip = search(val, db->rchild);

    return ip;
  }
