/******************   stack.c   ******************/

#include "global.h"
#include <stdlib.h>

static void removenode(void);

struct node
  {
    int val;          /* data value */
    struct node *prev;/* pointer to the previous node on the stack */
  };
     

struct node *top = NULL;/* pointer to the top element on the stack */

void clearstack(void)
  {
    while (top)  /* remove all nodes starting from the top node */
        removenode();
  }

void push(int n)
  {
    struct node *np;

    error = 0;

    np = (struct node *)malloc(sizeof(struct node));
    if (np)
      {
        np->val = n;   /* fill data value in the new node */
        np->prev = top;/* let it point to the current top node */
        top = np;      /* reset top to point to the new node */
      }
    else
        error = STACKFULL;
  }

int pop(void)
  {
    int val;

    error = 0;

    if (top)
      {
        val = top->val; /* fetch data value from the top node */
        removenode();   /* remove the top node */
        return val;
      }
    else
      {
        error = STACKEMPTY;
        return 0;
      }
  }

int stacksize(void)
  {
    struct node *np;
    int size = 0;

    for (np = top; np; np = np->prev) size++;
    return size;
  }

void printstack(void)
  {
    struct node *np;

    printf("stack:");
    for (np = top; np; np = np->prev)
        printf("%d ", np->val);
    printf("\n");
  }

static void removenode(void)
  {
    struct node *np;

    np = top;       /* save a pointer to the current top node */
    top = top->prev;/* reset top to point to the previous node */
    free(np);       /* delete what used to be the top node */
  }
